@@ -1,9 +1,7 @@
-# Copyright (C) 2020-2021
-# Author: Cesar Roman
-# Contact: cesar@thecesrom.dev
-
 """Exceptions module."""
 
+from __future__ import unicode_literals
+
 __all__ = ["ApplicationError", "TagError"]
 
 
